aboutsummaryrefslogtreecommitdiffstats
path: root/actionmailer/test/tmail_test.rb
diff options
context:
space:
mode:
Diffstat (limited to 'actionmailer/test/tmail_test.rb')
-rw-r--r--actionmailer/test/tmail_test.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/actionmailer/test/tmail_test.rb b/actionmailer/test/tmail_test.rb
index 5d895f3790..bd0190e661 100644
--- a/actionmailer/test/tmail_test.rb
+++ b/actionmailer/test/tmail_test.rb
@@ -8,8 +8,8 @@ class TMailMailTest < Test::Unit::TestCase
quoted_body = [expected].pack('*M')
m.body = quoted_body
assert_equal "something_with_underscores=\r\n", m.body.encoded
- # CHANGED: body returns object, not string, Changed m.body to m.body.decoded
- assert_equal expected, m.body.decoded
+ # CHANGED: body returns object, not string, Changed m.body to m.body.to_s
+ assert_equal expected, m.body.to_s
end
def test_nested_attachments_are_recognized_correctly